@@ -1,30 +1,37 @@
 # -*- coding: utf-8 -*-
 """
-    API - CRUD
+    API - GraphQL
 """
 
 # Fastberry
-from fastberry import GQL
-
+import fastberry as fb
 
 # Create your API (GraphQL) here.
-class Demo(GQL):
+
+
+@fb.gql
+class Demo:
     """Demo Api"""
 
-    schema = None
-    prefix = "demo"
+    class Meta:
+        """Meta-Data"""
+
+        app = False
+        model = None
 
     class Query:
         """Query"""
 
-        async def search(info) -> str:
+        async def search(info, pagination: fb.pagination) -> str:
             """Read the Docs"""
             print(info)
+            print(pagination.input)
             return "Search"
 
-        async def detail(info) -> str:
+        async def detail(info, item: fb.item) -> str:
             """Read the Docs"""
             print(info)
+            print(item.input)
             return "Detail"
 
     class Mutation:
