@@ -5,7 +5,7 @@
 import os.path
 
 import click
-import fastberry as fb
+import spoc
 
 from .action.plugin_maker import create_plugin
 from .shell import shell_print, unzip
@@ -23,10 +23,8 @@ from .shell import shell_print, unzip
 )
 def start_app(app_name, plugin):
     """Creates a Fastberry App Directory."""
-    Controller = fb.Fastberry()
-
     # Get Path(s)
-    apps_dir = Controller.base_dir / "apps"
+    apps_dir = spoc.base_dir / "apps"
     the_dir = apps_dir / app_name
 
     # Create Path(s)
